@@ -5,8 +5,8 @@ class NetBoxPTUEventsConfig(PluginConfig):
     name = 'ptueventsuserscomputers'
     verbose_name = 'Unacceptable events and users and computers'
     description = 'Add events related fields to devices and virtual machines, adds application systems'
-    version = '0.1.3.0001'
-    base_url = 'ptuevents'
+    version = '0.1.3.0002'
+    base_url = 'ptueventsuserscomputers'
     author = 'Artur Shamsiev'
     author_email = 'me@z-lab.me'
 
